@@ -1,4 +1,14 @@
 #================================================================================================================================
+warnhelpp = """
+Here is The help of Warns Module
+Admin COmmands
+ - /warn <userid> | <reason> or /warn <reason> in reply to a message: warn a user
+ - /removelastwarn: remove the last warn that a user has received
+ - /getwarns: list the warns that a user has received
+ - /resetwarns: reset all warns that a user has received
+ - /setwarnmode <kick/ban/mute>: set the warn mode for the chat
+"""
+
 ruless = """
 Here is the help for the Rules module:
 Admin Commands :-
